@@ -2,6 +2,7 @@ from googleapiclient.discovery import build
 import pickle
 import os
 import pandas as pd
+from pandas.core.frame import DataFrame
 from ..logger import logger
 
 
@@ -30,9 +31,10 @@ class Spreadsheet(object):
         if os.path.exists('token.pickle'):
             with open('token.pickle', 'rb') as token:
                 cred = pickle.load(token)
-        self.spreadsheet = build('sheets', 'v4', cache_discovery=False, credentials=cred).spreadsheets()
+        self.spreadsheet = build(
+            'sheets', 'v4', cache_discovery=False, credentials=cred).spreadsheets()
 
-    def load_table(self, range_: str) -> pd.DataFrame:
+    def load_table(self, range_: str) -> DataFrame:
         result = self.spreadsheet.values().get(
             spreadsheetId=self.spreadsheet_id, range=range_).execute()
 
@@ -45,8 +47,8 @@ class Spreadsheet(object):
         })
         values = result.get('values', [])
         sheet = pd.DataFrame(values, columns=values[0])
-        sheet = sheet.drop(drop=True)
-        sheet = sheet.reset_index()
+        sheet = sheet.drop(0)
+        sheet = sheet.reset_index(drop=True)
 
         logger.info({
             'action': 'get_table',
@@ -61,13 +63,10 @@ class Spreadsheet(object):
         logger.info({
             'action': 'get_values',
             'status': 'Success!',
-            'message': {
-                'value': values
-            }
         })
         return values
 
-    def append_dataframe(self, range_: str, dataframe):
+    def append_dataframe(self, range_: str, dataframe: DataFrame):
         logger.info({
             'action': 'set_dataframe',
             'status': 'running',
@@ -77,6 +76,7 @@ class Spreadsheet(object):
         })
         self.spreadsheet.values().append(spreadsheetId=self.spreadsheet_id,
                                          valueInputOption="USER_ENTERED",
+                                         insertDataOption='OVERWRITE',
                                          range=range_,
                                          body={"values": dataframe.values.tolist()}).execute()
 
@@ -85,17 +85,17 @@ class Spreadsheet(object):
             'status': 'Success!',
         })
 
-    def set_values(self, range_: str, values):
+    def set_values(self, range_: str, values: list):
         self.spreadsheet.values().update(spreadsheetId=self.spreadsheet_id,
                                          valueInputOption="USER_ENTERED",
                                          range=range_,
-                                         body={"values": [[values]]}).execute()
+                                         body={"values": values}).execute()
         logger.info({
             'action': 'set_values',
             'status': 'Success!',
         })
 
-    def load_metadata(self) -> SpreadsheetMetadata.sheet_meta_dict:
+    def load_metadata(self) -> list:
         sheet_metadata = self.spreadsheet.get(
             spreadsheetId=self.spreadsheet_id).execute()
         sheets = sheet_metadata.get('sheets', '')
@@ -121,8 +121,8 @@ class Spreadsheet(object):
         logger.info({
             'action': 'create_sheet',
             'status': 'running',
-            'message':{
-                'sheet_name':sheet_name
+            'message': {
+                'sheet_name': sheet_name
             }
         })
 
@@ -130,8 +130,8 @@ class Spreadsheet(object):
         response = self.spreadsheet.batchUpdate(
             spreadsheetId=self.spreadsheet_id, body=body).execute()
         sheetid = response['replies'][0]['addSheet']['properties']['sheetId']
-        return {'sheet_id':sheetid}
-    
+        return {'sheet_id': sheetid}
+
     def delete_sheet(self, sheet_id: str):
         requests = [{
             'deleteSheet': {
@@ -142,17 +142,22 @@ class Spreadsheet(object):
         logger.info({
             'action': 'delete_sheet',
             'status': 'running',
-            'message':{
-                'sheet_id':sheet_id
+            'message': {
+                'sheet_id': sheet_id
             }
         })
 
         body = {'requests': requests}
         self.spreadsheet.batchUpdate(
             spreadsheetId=self.spreadsheet_id, body=body).execute()
-        
+
         logger.info({
             'action': 'delete_sheet',
             'status': 'Success!'
         })
 
+    def clear_range(self, range_: str):
+        self.spreadsheet.values().clear(spreadsheetId=self.spreadsheet_id,
+                                        range=range_, body={}).execute()
+        
+        logger.info({'action': 'clear_range', 'status': 'Success!'})
